@@ -95,7 +95,7 @@ static void printKey(Display *pDisplay, int cKeys)
 static void dumpLayout(Display *pDisplay)
 {
     LogRel(("Your keyboard layout does not appear to be fully supported by\n"
-            "VirtualBox. If you are experiencing keyboard problems this.\n"
+            "VirtualBox. If you are experiencing keyboard problems this\n"
             "information may help us to resolve them.\n"
             "(Note: please tell us if you are using a custom layout.)\n\n"
             "The correct table for your layout is:\n"));
